PushManyUnchecked

Trait PushManyUnchecked 

pub trait PushManyUnchecked<T> {
    // Required method
    unsafe fn push_many_unchecked(&mut self, value: T, count: usize);
}
A trait to push many times without the capacity check.

Required Methods

unsafe fn push_many_unchecked(&mut self, value: T, count: usize)

Appends an element count times to the back of a collection without the capacity check.

Safety

The capacity of the collection must be sufficient for the new items.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<V: GenericVec<Item = i8>> PushManyUnchecked<i8> for V

Source

impl<V: GenericVec<Item = u8>> PushManyUnchecked<u8> for V