PushStrUnchecked

Trait PushStrUnchecked 

pub trait PushStrUnchecked {
    // Required method
    unsafe fn push_str_unchecked(&mut self, string: &str);
}
A trait for push_str without the capacity check.

Required Methods

unsafe fn push_str_unchecked(&mut self, string: &str)

Appends a given string slice onto the end of this collection without the capacity check.

Safety

The capacity of the collection must be sufficient for the appended string.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S: GenericString> PushStrUnchecked for S