pub trait CopyFromSliceUnchecked<T> {
// Required method
unsafe fn copy_from_slice_unchecked(&mut self, src: &[T]);
}Expand description
A trait for copy_from_slice without the length check.
Required Methods
Sourceunsafe fn copy_from_slice_unchecked(&mut self, src: &[T])
unsafe fn copy_from_slice_unchecked(&mut self, src: &[T])
Copies all elements from src into self without the length check.
Safety
The length of self must be equal to the length of src.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".